#include <cstdio>
#include <gagagugu.h>

int main()
{
    printStuff();
    return 0;
}
